==> sqliteman-0.99-20070403.tar.gz: sqliteman-0.99/sqliteman/icons/cmake_install.cmake <==
# Install script for directory: /home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons

# Set the install prefix
IF(NOT DEFINED CMAKE_INSTALL_PREFIX)
  SET(CMAKE_INSTALL_PREFIX "/home/pvanek/sqliteman-svn/TESTBUILD")
ENDIF(NOT DEFINED CMAKE_INSTALL_PREFIX)
STRING(REGEX REPLACE "/$" "" CMAKE_INSTALL_PREFIX "${CMAKE_INSTALL_PREFIX}")

# Set the install configuration name.
IF(NOT CMAKE_INSTALL_CONFIG_NAME)
  IF(BUILD_TYPE)
    STRING(REGEX REPLACE "^[^A-Za-z0-9_]+" ""
           CMAKE_INSTALL_CONFIG_NAME "${BUILD_TYPE}")
  ELSE(BUILD_TYPE)
    SET(CMAKE_INSTALL_CONFIG_NAME "RELEASE")
  ENDIF(BUILD_TYPE)
  MESSAGE(STATUS "Install configuration: \"${CMAKE_INSTALL_CONFIG_NAME}\"")
ENDIF(NOT CMAKE_INSTALL_CONFIG_NAME)

# Set the component getting installed.
IF(NOT CMAKE_INSTALL_COMPONENT)
  IF(COMPONENT)
    MESSAGE(STATUS "Install component: \"${COMPONENT}\"")
    SET(CMAKE_INSTALL_COMPONENT "${COMPONENT}")
  ELSE(COMPONENT)
    SET(CMAKE_INSTALL_COMPONENT)
  ENDIF(COMPONENT)
ENDIF(NOT CMAKE_INSTALL_COMPONENT)

FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/clear_table_contents.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/document-new.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/document-save.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/key.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/sqliteman.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/trigger.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/database.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/document-open.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/index.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/runexplain.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/system.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/view.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/delete_table_row.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/document-save-as.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/insert_table_row.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/runsql.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/table.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/database_commit.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/database_rollback.png")

==> sqliteman-0.99-20070509.tar.gz: sqliteman-0.99/sqliteman/icons/cmake_install.cmake <==
# Install script for directory: /home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons

# Set the install prefix
IF(NOT DEFINED CMAKE_INSTALL_PREFIX)
  SET(CMAKE_INSTALL_PREFIX "/home/pvanek/sqliteman-svn/TESTBUILD")
ENDIF(NOT DEFINED CMAKE_INSTALL_PREFIX)
STRING(REGEX REPLACE "/$" "" CMAKE_INSTALL_PREFIX "${CMAKE_INSTALL_PREFIX}")

# Set the install configuration name.
IF(NOT CMAKE_INSTALL_CONFIG_NAME)
  IF(BUILD_TYPE)
    STRING(REGEX REPLACE "^[^A-Za-z0-9_]+" ""
           CMAKE_INSTALL_CONFIG_NAME "${BUILD_TYPE}")
  ELSE(BUILD_TYPE)
    SET(CMAKE_INSTALL_CONFIG_NAME "Debug")
  ENDIF(BUILD_TYPE)
  MESSAGE(STATUS "Install configuration: \"${CMAKE_INSTALL_CONFIG_NAME}\"")
ENDIF(NOT CMAKE_INSTALL_CONFIG_NAME)

# Set the component getting installed.
IF(NOT CMAKE_INSTALL_COMPONENT)
  IF(COMPONENT)
    MESSAGE(STATUS "Install component: \"${COMPONENT}\"")
    SET(CMAKE_INSTALL_COMPONENT "${COMPONENT}")
  ELSE(COMPONENT)
    SET(CMAKE_INSTALL_COMPONENT)
  ENDIF(COMPONENT)
ENDIF(NOT CMAKE_INSTALL_COMPONENT)

FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/clear_table_contents.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/document-new.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/document-save.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/key.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/sqliteman.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/trigger.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/database.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/document-open.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/index.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/runexplain.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/system.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/view.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/delete_table_row.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/document-save-as.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/insert_table_row.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/runsql.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/table.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/database_commit.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/icons" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/icons/database_rollback.png")
